@@ -80,7 +80,7 @@ colspml.mle <- function(x, tol = 1e-07, maxiters = 100, parallel = FALSE) {
 #[export]
 colcauchy.mle <- function (x, tol = 1e-07, maxiters = 100, parallel = FALSE) {
     res <- .Call(Rfast2_colcauchy_mle, x, tol, parallel, maxiters)
-    colnames(res) <- c("loglik", "location", "scale")
+    colnames(res) <- c("location", "scale", "loglik")
     res
 }
 
@@ -88,7 +88,7 @@ colcauchy.mle <- function (x, tol = 1e-07, maxiters = 100, parallel = FALSE) {
 #[export]
 colbeta.mle <- function(x, tol = 1e-07, maxiters = 100, parallel = FALSE) {
     res <- .Call(Rfast2_colbeta_mle, x, tol, parallel, maxiters)
-    colnames(res) <- c("alpha", "betag", "loglik")
+    colnames(res) <- c("alpha", "beta", "loglik")
     res
 }
 
