@@ -14,7 +14,7 @@ pca <- function(x, center = TRUE, scale = TRUE, k = NULL, vectors = FALSE) {
      } else {
        xsvd <- svd( x, nu = 0)
        values <- xsvd$d^2 / (n - 1)
-       vectors <- xsvd$v[, 1:k]
+       vectors <- xsvd$v[, 1:k, drop = FALSE]
      }
      res <- list(values = values[1:k], vectors = vectors)
    }
